History
-------

.. _Digital Creations: http://www.digicool.com/
.. _wxPython: http://www.wxpython.org/

This module was started by Andrew Kuchling (amk) to remove the
dependency on SWIG in a package by Gregory P. Smith who based his work
on a similar package by Robin Dunn which wrapped Berkeley DB 2.7.x.

Development then returned full circle back to Robin Dunn working in
behalf of `Digital Creations`_ to complete the SWIG-less wrapping of the DB
3.x API and to build a solid unit test suite. Having completed that,
Robin was now busy with another project (wxPython_) and Greg returned as
maintainer.

.. I can't use tildes because my ZOPE configuration.
.. Something to fix in the future.

`Jesus Cea Avion <https://www.jcea.es/programacion/pybsddb.htm>`__
is the maintainer of this code since February 2008, and ported it
to Python 3.x.

In 2020, after Python 2.7 sunset, this library was renamed to
"berkeleydb" and it was made Python 3 only.
